==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/nl/coptic.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "deze zaterdag",
	"field-sat-relative+1": "volgende week zaterdag",
	"field-dayperiod": "AM/PM",
	"field-sun-relative+-1": "afgelopen zondag",
	"field-mon-relative+-1": "afgelopen maandag",
	"field-minute": "Minuut",
	"field-day-relative+-1": "gisteren",
	"field-weekday": "Dag van de week",
	"field-day-relative+-2": "eergisteren",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-era": "Tijdperk",
	"field-hour": "Uur",
	"field-sun-relative+0": "deze zondag",
	"field-sun-relative+1": "volgende week zondag",
	"months-standAlone-abbr": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba'unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-wed-relative+-1": "afgelopen woensdag",
	"field-day-relative+0": "vandaag",
	"field-day-relative+1": "morgen",
	"field-day-relative+2": "overmorgen",
	"field-tue-relative+0": "deze dinsdag",
	"field-zone": "Zone",
	"field-tue-relative+1": "volgende week dinsdag",
	"field-week-relative+-1": "vorige week",
	"field-year-relative+0": "dit jaar",
	"field-year-relative+1": "volgend jaar",
	"field-sat-relative+-1": "afgelopen zaterdag",
	"field-year-relative+-1": "vorig jaar",
	"field-year": "Jaar",
	"field-fri-relative+0": "deze vrijdag",
	"field-fri-relative+1": "volgende week vrijdag",
	"months-standAlone-wide": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba'unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-week": "Week",
	"field-week-relative+0": "deze week",
	"field-week-relative+1": "volgende week",
	"months-format-abbr": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba'unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-month-relative+0": "deze maand",
	"field-month": "Maand",
	"field-month-relative+1": "volgende maand",
	"field-fri-relative+-1": "afgelopen vrijdag",
	"field-second": "Seconde",
	"field-tue-relative+-1": "afgelopen dinsdag",
	"field-day": "Dag",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-mon-relative+0": "deze maandag",
	"field-mon-relative+1": "volgende week maandag",
	"field-thu-relative+0": "deze donderdag",
	"field-second-relative+0": "nu",
	"field-thu-relative+1": "volgende week donderdag",
	"months-format-wide": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba'unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-wed-relative+0": "deze woensdag",
	"field-wed-relative+1": "volgende week woensdag",
	"field-month-relative+-1": "vorige maand",
	"field-thu-relative+-1": "afgelopen donderdag"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/nl/coptic.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "deze zaterdag",
	"field-sat-relative+1": "volgende week zaterdag",
	"field-dayperiod": "a.m./p.m.",
	"field-sun-relative+-1": "afgelopen zondag",
	"field-mon-relative+-1": "afgelopen maandag",
	"field-minute": "Minuut",
	"field-day-relative+-1": "gisteren",
	"field-weekday": "Dag van de week",
	"field-day-relative+-2": "eergisteren",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-era": "Tijdperk",
	"field-hour": "Uur",
	"field-sun-relative+0": "deze zondag",
	"field-sun-relative+1": "volgende week zondag",
	"months-standAlone-abbr": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba’unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-wed-relative+-1": "afgelopen woensdag",
	"field-day-relative+0": "vandaag",
	"field-day-relative+1": "morgen",
	"field-day-relative+2": "overmorgen",
	"field-tue-relative+0": "deze dinsdag",
	"field-zone": "Zone",
	"field-tue-relative+1": "volgende week dinsdag",
	"field-week-relative+-1": "vorige week",
	"field-year-relative+0": "dit jaar",
	"field-year-relative+1": "volgend jaar",
	"field-sat-relative+-1": "afgelopen zaterdag",
	"field-year-relative+-1": "vorig jaar",
	"field-year": "Jaar",
	"field-fri-relative+0": "deze vrijdag",
	"field-fri-relative+1": "volgende week vrijdag",
	"months-standAlone-wide": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba’unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-week": "Week",
	"field-week-relative+0": "deze week",
	"field-week-relative+1": "volgende week",
	"months-format-abbr": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba’unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-month-relative+0": "deze maand",
	"field-month": "Maand",
	"field-month-relative+1": "volgende maand",
	"field-fri-relative+-1": "afgelopen vrijdag",
	"field-second": "Seconde",
	"field-tue-relative+-1": "afgelopen dinsdag",
	"field-day": "Dag",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-mon-relative+0": "deze maandag",
	"field-mon-relative+1": "volgende week maandag",
	"field-thu-relative+0": "deze donderdag",
	"field-second-relative+0": "nu",
	"field-thu-relative+1": "volgende week donderdag",
	"months-format-wide": [
		"Tut",
		"Babah",
		"Hatur",
		"Kiyahk",
		"Tubah",
		"Amshir",
		"Baramhat",
		"Baramundah",
		"Bashans",
		"Ba’unah",
		"Abib",
		"Misra",
		"Nasi"
	],
	"field-wed-relative+0": "deze woensdag",
	"field-wed-relative+1": "volgende week woensdag",
	"field-month-relative+-1": "vorige maand",
	"field-thu-relative+-1": "afgelopen donderdag"
}
//end v1.x content
);
